tinyMCE.addI18n('de.advimage_dlg',{
tab_general:"Allgemein",
tab_appearance:"Aussehen",
tab_advanced:"Erweitert",
general:"Allgemein",
title:"Titel",
preview:"Vorschau",
constrain_proportions:"Seitenverh\u00E4ltnis beibehalten",
langdir:"Schriftrichtung",
langcode:"Sprachcode",
long_desc:"Ausf\u00FChrliche Beschreibung",
style:"Format",
classes:"Klassen",
ltr:"Links nach rechts",
rtl:"Rechts nach links",
id:"ID",
map:"Image-Map",
swap_image:"Bild austauschen",
alt_image:"Alternatives Bild",
mouseover:"bei Mauskontakt",
mouseout:"bei keinem Mauskontakt",
misc:"Verschiedenes",
example_img:"Aussehen der Vorschau",
missing_alt:"Wollen Sie wirklich keine Beschreibung eingeben? Bestimmte Benutzer mit k\u00F6rperlichen Einschr\u00E4nkungen k\u00F6nnen so nicht darauf zugreifen, ebenso solche, die einen Textbrowser benutzen oder die Anzeige von Bildern deaktiviert haben.",
dialog_title:"Bild einf\u00FCgen/bearbeiten",
src:"Adresse",
alt:"Beschreibung",
list:"Bilderliste",
border:"Rahmen",
dimensions:"Ausma\u00DFe",
vspace:"Vertikaler Abstand",
hspace:"Horizontaler Abstand",
align:"Ausrichtung",
align_baseline:"Zeile",
align_top:"Oben",
align_middle:"Mittig",
align_bottom:"Unten",
align_texttop:"Oben im Text",
align_textbottom:"Unten im Text",
align_left:"Links",
align_right:"Rechts",
image_list:"Bilderliste"
});
